@@ -19,15 +19,18 @@
 checkIfDbmsIsSupported <- function(dbms) {
   supportedDbmss <- c(
     "oracle",
+    "hive",
     "postgresql",
     "redshift",
     "sql server",
     "pdw",
     "netezza",
+    "impala",
     "bigquery",
     "sqlite",
     "sqlite extended",
-    "spark"
+    "spark",
+    "hive"
   )
   if (!dbms %in% supportedDbmss) {
     abort(sprintf(
@@ -510,11 +513,11 @@ connect <- function(connectionDetails = NULL,
   }
   if (dbms == "hive") {
     inform("Connecting using Hive driver")
-    jarPath <- findPathToJar("^hive-jdbc-standalone\\.jar$", pathToDriver)
+    jarPath <- findPathToJar("^hive-jdbc-([.0-9]+-)*standalone\\.jar$", pathToDriver)
     driver <- getJbcDriverSingleton("org.apache.hive.jdbc.HiveDriver", jarPath)
     
     if (missing(connectionString) || is.null(connectionString)) {
-      connectionString <- paste0("jdbc:hive2://", server, ":", port)
+      connectionString <- paste0("jdbc:hive2://", server, ":", port, "/")
       if (!missing(extraSettings) && !is.null(extraSettings)) {
         connectionString <- paste0(connectionString, ";", extraSettings)
       }
