@@ -238,3 +238,12 @@ test_that("Error is thrown when using incorrect dbms argument", {
 test_that("getAvailableJavaHeapSpace returns a positive number", {
   expect_gt(getAvailableJavaHeapSpace(), 0)
 })
+
+test_that("Error is thrown when forgetting password", {
+  details <- createConnectionDetails(
+    dbms = "postgresql",
+    user = Sys.getenv("CDM5_POSTGRESQL_USER"),
+    server = Sys.getenv("CDM5_POSTGRESQL_SERVER")
+  )
+  expect_error(connection <- connect(details), "Connection propery 'password' is NULL")
+})
